@@ -1,31 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- */
-
-/**
- * SECTION:gcm-calibrate
- * @short_description: Calibration object
- *
- * This object allows calibration functionality using CMS.
- */
-
 #include "config.h"
 
 #include <glib/gi18n.h>
@@ -35,7 +7,6 @@
 #include "gcm-calibrate.h"
 #include "gcm-utils.h"
 #include "gcm-brightness.h"
-#include "gcm-calibrate-dialog.h"
 #include "gcm-exif.h"
 
 static void     gcm_calibrate_finalize	(GObject     *object);
@@ -49,13 +20,11 @@ static void     gcm_calibrate_finalize	(GObject     *object);
  **/
 struct _GcmCalibratePrivate
 {
-	GcmCalibrateReferenceKind	 reference_kind;
-	GcmCalibrateDeviceKind		 calibrate_device_kind;
+	GcmCalibrateDisplayKind		 display_kind;
 	GcmCalibratePrintKind		 print_kind;
 	GcmCalibratePrecision		 precision;
+	GcmCalibrateReferenceKind	 reference_kind;
 	CdSensor			*sensor;
-	CdSensorKind			 sensor_kind;
-	GcmCalibrateDialog		*calibrate_dialog;
 	CdDeviceKind			 device_kind;
 	CdColorXYZ			*xyz;
 	gchar				*output_name;
@@ -69,9 +38,12 @@ struct _GcmCalibratePrivate
 	gchar				*serial;
 	gchar				*device;
 	gchar				*working_path;
-	GSettings			*settings;
+	GtkWidget			*content_widget;
+	GPtrArray			*old_message;
+	GPtrArray			*old_title;
 };
 
+
 enum {
 	PROP_0,
 	PROP_BASENAME,
@@ -81,7 +53,7 @@ enum {
 	PROP_DEVICE,
 	PROP_MANUFACTURER,
 	PROP_REFERENCE_KIND,
-	PROP_CALIBRATE_DEVICE_KIND,
+	PROP_DISPLAY_KIND,
 	PROP_PRINT_KIND,
 	PROP_DEVICE_KIND,
 	PROP_SENSOR_KIND,
@@ -95,8 +67,30 @@ enum {
 	PROP_LAST
 };
 
+enum {
+	SIGNAL_TITLE_CHANGED,
+	SIGNAL_MESSAGE_CHANGED,
+	SIGNAL_IMAGE_CHANGED,
+	SIGNAL_INTERACTION_REQUIRED,
+	SIGNAL_LAST
+};
+
+static guint signals[SIGNAL_LAST] = { 0 };
+
 G_DEFINE_TYPE (GcmCalibrate, gcm_calibrate, G_TYPE_OBJECT)
 
+void
+gcm_calibrate_set_content_widget (GcmCalibrate *calibrate, GtkWidget *widget)
+{
+	calibrate->priv->content_widget = widget;
+}
+
+GtkWidget *
+gcm_calibrate_get_content_widget (GcmCalibrate *calibrate)
+{
+	return calibrate->priv->content_widget;
+}
+
 /**
  * gcm_calibrate_mkdir_with_parents:
  **/
@@ -147,14 +141,9 @@ gchar *
 gcm_calibrate_get_profile_description (GcmCalibrate *calibrate)
 {
 	gchar *text;
-	GDate *date = NULL;
 	const gchar *description;
 	GcmCalibratePrivate *priv = calibrate->priv;
 
-	/* create date and set it to now */
-	date = g_date_new ();
-	g_date_set_time_t (date, time (NULL));
-
 	/* we've got something set */
 	if (priv->description != NULL) {
 		description = priv->description;
@@ -164,9 +153,7 @@ gcm_calibrate_get_profile_description (GcmCalibrate *calibrate)
 	}
 
 	/* get description */
-	text = g_strdup_printf ("%s, %s (%04i-%02i-%02i)", priv->device, description, date->year, date->month, date->day);
-
-	g_date_free (date);
+	text = g_strdup_printf ("%s, %s", priv->device, description);
 	return text;
 }
 
@@ -322,8 +309,6 @@ gcm_calibrate_set_from_device (GcmCalibrate *calibrate,
 
 	/* do not refcount */
 	calibrate->priv->sensor = sensor;
-	calibrate->priv->sensor_kind = cd_sensor_get_kind (sensor);
-	g_object_notify (G_OBJECT (calibrate), "sensor-kind");
 
 	/* set the proper values */
 	g_object_set (calibrate,
@@ -339,7 +324,7 @@ gcm_calibrate_set_from_device (GcmCalibrate *calibrate,
 
 	/* display specific properties */
 	if (kind == CD_DEVICE_KIND_DISPLAY) {
-		native_device = cd_device_get_metadata_item (device, "XRANDR_name");
+		native_device = cd_device_get_metadata_item (device, CD_DEVICE_METADATA_XRANDR_NAME);
 		if (native_device == NULL) {
 			g_set_error (error,
 				     GCM_CALIBRATE_ERROR,
@@ -403,69 +388,23 @@ out:
 	return ret;
 }
 
-/**
- * gcm_calibrate_get_display_kind:
- **/
-static gboolean
-gcm_calibrate_get_display_kind (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
-{
-	gboolean ret = TRUE;
-	const gchar *title;
-	const gchar *message;
-	GtkResponseType response;
-	GcmCalibratePrivate *priv = calibrate->priv;
-
-	/* TRANSLATORS: title, usually we can tell based on the EDID data or output name */
-	title = _("Could not detect screen type");
-
-	/* TRANSLATORS: dialog message */
-	message = _("Please indicate if the screen you are trying to profile is an LCD, CRT or a projector.");
-
-	/* show the ui */
-	gcm_calibrate_dialog_set_window (priv->calibrate_dialog, window);
-	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_DISPLAY_TYPE, title, message);
-	gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, FALSE);
-	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-	response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-	if (response != GTK_RESPONSE_OK) {
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "user did not choose crt or lcd");
-		ret = FALSE;
-		goto out;
-	}
-
-	/* copy */
-	g_object_get (priv->calibrate_dialog, "device-kind", &priv->calibrate_device_kind, NULL);
-
+#if 0
 	/* can this device support projectors? */
-	if (priv->calibrate_device_kind == GCM_CALIBRATE_DEVICE_KIND_PROJECTOR &&
+	if (priv->display_kind == GCM_CALIBRATE_DEVICE_KIND_PROJECTOR &&
 	    !cd_sensor_has_cap (priv->sensor, CD_SENSOR_CAP_PROJECTOR)) {
 		/* TRANSLATORS: title, the hardware calibration device does not support projectors */
 		title = _("Could not calibrate and profile using this color measuring instrument");
 
 		/* TRANSLATORS: dialog message */
 		message = _("This color measuring instrument is not designed to support calibration and profiling projectors.");
-
-		/* ask the user again */
-		gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
-		gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, FALSE);
-		gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-		response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-		if (response != GTK_RESPONSE_OK) {
-			gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-			g_set_error_literal (error,
-					     GCM_CALIBRATE_ERROR,
-					     GCM_CALIBRATE_ERROR_NO_SUPPORT,
-					     "hardware not capable of profiling a projector");
-			ret = FALSE;
-			goto out;
-		}
 	}
-out:
-	return ret;
+#endif
+
+void
+gcm_calibrate_set_sensor (GcmCalibrate *calibrate, CdSensor *sensor)
+{
+	/* do not refcount */
+	calibrate->priv->sensor = sensor;
 }
 
 /**
@@ -492,72 +431,16 @@ gcm_calibrate_set_working_path (GcmCalibrate *calibrate, GError **error)
 	return ret;
 }
 
-/**
- * gcm_calibrate_get_precision:
- **/
-static GcmCalibratePrecision
-gcm_calibrate_get_precision (GcmCalibrate *calibrate, GError **error)
-{
-	GcmCalibratePrecision precision = GCM_CALIBRATE_PRECISION_UNKNOWN;
-	const gchar *title;
-	GString *string;
-	GtkResponseType response;
-	GcmCalibratePrivate *priv = calibrate->priv;
-
-	string = g_string_new ("");
-
-	/* TRANSLATORS: dialog title */
-	title = _("Profile Precision");
-
-	/* TRANSLATORS: this is the message body for the chart selection */
-	g_string_append (string, _("A higher precision profile provides higher accuracy in color matching but requires more time for reading the color patches."));
-
-	/* TRANSLATORS: this is the message body for the chart selection */
-	g_string_append_printf (string, "\n%s", _("For a typical workflow, a normal precision profile is sufficient."));
-
-	/* printer specific options */
-	if (priv->device_kind == CD_DEVICE_KIND_PRINTER) {
-		/* TRANSLATORS: dialog message, preface */
-		g_string_append_printf (string, "\n%s", _("The high precision profile also requires more paper and printer ink."));
-	}
-
-	/* push new messages into the UI */
-	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_PRECISION, title, string->str);
-	gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, FALSE);
-	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-	response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-	if (response != GTK_RESPONSE_OK) {
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "user did not choose precision type and ask is specified in GSettings");
-		goto out;
-	}
-
-	/* copy */
-	g_object_get (priv->calibrate_dialog, "precision", &precision, NULL);
-out:
-	if (string != NULL)
-		g_string_free (string, TRUE);
-	return precision;
-}
-
 /**
  * gcm_calibrate_spotread:
  **/
 gboolean
-gcm_calibrate_spotread (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_spotread (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	GcmCalibratePrivate *priv = calibrate->priv;
 	gboolean ret;
 
-	/* set the per-profile filename */
-	ret = gcm_calibrate_set_working_path (calibrate, error);
-	if (!ret)
-		goto out;
-
 	/* coldplug source */
 	if (klass->calibrate_spotread == NULL) {
 		ret = FALSE;
@@ -569,43 +452,49 @@ gcm_calibrate_spotread (GcmCalibrate *calibrate, GtkWindow *window, GError **err
 	}
 
 	/* proxy */
-	ret = klass->calibrate_spotread (calibrate, priv->sensor, window, error);
+	ret = klass->calibrate_spotread (calibrate, device, priv->sensor, window, error);
 out:
 	return ret;
 }
 
+/**
+ * gcm_calibrate_interaction:
+ **/
+void
+gcm_calibrate_interaction (GcmCalibrate *calibrate, GtkResponseType response)
+{
+	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
+
+	/* coldplug source */
+	if (klass->interaction == NULL)
+		return;
+
+	/* proxy */
+	klass->interaction (calibrate, response);
+}
+
 /**
  * gcm_calibrate_display:
  **/
 gboolean
-gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_display (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
-	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	gboolean ret = TRUE;
-	const gchar *hardware_device;
-	gboolean ret_tmp;
-	GString *string = NULL;
-	GcmBrightness *brightness = NULL;
-	guint percentage = G_MAXUINT;
-	GtkResponseType response;
-	GError *error_tmp = NULL;
-	gchar *precision = NULL;
+	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	GcmCalibratePrivate *priv = calibrate->priv;
 
-	/* coldplug source */
-	if (priv->output_name == NULL) {
-		ret = FALSE;
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_INTERNAL,
-				     "no output name set");
-		goto out;
+	/* set basename */
+	gcm_calibrate_set_basename (calibrate);
+#if 0
+	const gchar *hardware_device;
+	/* get device, harder */
+	hardware_device = cd_sensor_get_model (priv->sensor);
+	if (hardware_device == NULL) {
+		/* TRANSLATORS: this is the formattted custom profile description.
+		 * "Custom" refers to the fact that it's user generated */
+		hardware_device = _("Custom");
 	}
-
-	/* set the per-profile filename */
-	ret = gcm_calibrate_set_working_path (calibrate, error);
-	if (!ret)
-		goto out;
+#endif
 
 	/* coldplug source */
 	if (klass->calibrate_display == NULL) {
@@ -617,127 +506,9 @@ gcm_calibrate_display (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 		goto out;
 	}
 
-	/* get device, harder */
-	hardware_device = cd_sensor_get_model (priv->sensor);
-	if (hardware_device == NULL) {
-		/* TRANSLATORS: this is the formattted custom profile description.
-		 * "Custom" refers to the fact that it's user generated */
-		hardware_device = g_strdup (_("Custom"));
-	}
-
-	/* set display specific properties */
-	g_object_set (calibrate,
-		      "device", hardware_device,
-		      NULL);
-
-	/* this wasn't previously set */
-	if (priv->calibrate_device_kind == GCM_CALIBRATE_DEVICE_KIND_UNKNOWN) {
-		ret = gcm_calibrate_get_display_kind (calibrate, window, error);
-		if (!ret)
-			goto out;
-	}
-
-	/* get default precision */
-	priv->precision = g_settings_get_enum (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
-	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-		priv->precision = gcm_calibrate_get_precision (calibrate, error);
-		if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-			ret = FALSE;
-			goto out;
-		}
-	}
-
-	/* show a warning for external monitors */
-	ret = gcm_utils_output_is_lcd_internal (priv->output_name);
-	if (!ret) {
-		string = g_string_new ("");
-
-		/* TRANSLATORS: dialog message, preface */
-		g_string_append_printf (string, "%s\n", _("Before calibrating the display, it is recommended to configure your display with the following settings to get optimal results."));
-
-		/* TRANSLATORS: dialog message, preface */
-		g_string_append_printf (string, "%s\n\n", _("You may want to consult the owner's manual for your display on how to achieve these settings."));
-
-		/* TRANSLATORS: dialog message, bullet item */
-		g_string_append_printf (string, "• %s\n", _("Reset your display to the factory defaults."));
-
-		/* TRANSLATORS: dialog message, bullet item */
-		g_string_append_printf (string, "• %s\n", _("Disable dynamic contrast if your display has this feature."));
-
-		/* TRANSLATORS: dialog message, bullet item */
-		g_string_append_printf (string, "• %s", _("Configure your display with custom color settings and ensure the RGB channels are set to the same values."));
-
-		/* TRANSLATORS: dialog message, addition to bullet item */
-		g_string_append_printf (string, " %s\n", _("If custom color is not available then use a 6500K color temperature."));
-
-		/* TRANSLATORS: dialog message, bullet item */
-		g_string_append_printf (string, "• %s\n", _("Adjust the display brightness to a comfortable level for prolonged viewing."));
-
-		/* TRANSLATORS: dialog message, suffix */
-		g_string_append_printf (string, "\n%s\n", _("For best results, the display should have been powered for at least 15 minutes before starting the calibration."));
-
-		/* TRANSLATORS: window title */
-		gcm_calibrate_dialog_set_window (priv->calibrate_dialog, window);
-		gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, _("Display setup"), string->str);
-		gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, TRUE);
-		gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-		response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-		if (response != GTK_RESPONSE_OK) {
-			gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-			g_set_error_literal (error,
-					     GCM_CALIBRATE_ERROR,
-					     GCM_CALIBRATE_ERROR_USER_ABORT,
-					     "user did not follow calibration steps");
-			ret = FALSE;
-			goto out;
-		}
-	}
-
-	/* create new helper objects */
-	brightness = gcm_brightness_new ();
-
-	/* if we are an internal LCD, we need to set the brightness to maximum */
-	ret = gcm_utils_output_is_lcd_internal (priv->output_name);
-	if (ret) {
-		/* get the old brightness so we can restore state */
-		ret = gcm_brightness_get_percentage (brightness, &percentage, &error_tmp);
-		if (!ret) {
-			g_warning ("failed to get brightness: %s", error_tmp->message);
-			g_error_free (error_tmp);
-			/* not fatal */
-			error_tmp = NULL;
-		}
-
-		/* set the new brightness */
-		ret = gcm_brightness_set_percentage (brightness, 100, &error_tmp);
-		if (!ret) {
-			g_warning ("failed to set brightness: %s", error_tmp->message);
-			g_error_free (error_tmp);
-			/* not fatal */
-			error_tmp = NULL;
-		}
-	}
-
 	/* proxy */
-	ret = klass->calibrate_display (calibrate, priv->sensor, window, error);
+	ret = klass->calibrate_display (calibrate, device, priv->sensor, window, error);
 out:
-	/* restore brightness */
-	if (percentage != G_MAXUINT) {
-		/* set the new brightness */
-		ret_tmp = gcm_brightness_set_percentage (brightness, percentage, &error_tmp);
-		if (!ret_tmp) {
-			g_warning ("failed to restore brightness: %s", error_tmp->message);
-			g_error_free (error_tmp);
-			/* not fatal */
-			error = NULL;
-		}
-	}
-
-	if (brightness != NULL)
-		g_object_unref (brightness);
-	if (string != NULL)
-		g_string_free (string, TRUE);
-	g_free (precision);
 	return ret;
 }
 
@@ -918,53 +689,17 @@ gcm_calibrate_file_chooser_get_working_path (GcmCalibrate *calibrate, GtkWindow
  * gcm_calibrate_printer:
  **/
 gboolean
-gcm_calibrate_printer (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
 	gboolean ret = FALSE;
-	const gchar *title;
-	const gchar *message;
 	gchar *ptr;
-	GtkWindow *window_tmp;
-	GtkResponseType response;
+	GtkWindow *window_tmp = NULL;
 	gchar *precision = NULL;
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 	GcmCalibratePrivate *priv = calibrate->priv;
 
-	/* TRANSLATORS: title, you can profile all at once, or in steps */
-	title = _("Please choose a profiling mode");
-
-	/* TRANSLATORS: dialog message. Test patches are pages of colored squares
-	 * that are printed with a printer, and then read in with a calibration
-	 * device to create a profile */
-	message = _("Please indicate if you want to profile a local printer, generate some test patches, or profile using existing test patches.");
-
-	/* push new messages into the UI */
-	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_PRINT_MODE, title, message);
-	gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, FALSE);
-	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-	response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-	if (response != GTK_RESPONSE_OK) {
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "user did not choose print mode");
-		ret = FALSE;
-		goto out;
-	}
-
-	/* get default precision */
-	priv->precision = g_settings_get_enum (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
-	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-		priv->precision = gcm_calibrate_get_precision (calibrate, error);
-		if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-			ret = FALSE;
-			goto out;
-		}
-	}
-
 	/* copy */
-	g_object_get (priv->calibrate_dialog, "print-kind", &priv->print_kind, NULL);
+	g_object_get (NULL, "print-kind", &priv->print_kind, NULL);
 
 	if (priv->print_kind != GCM_CALIBRATE_PRINT_KIND_ANALYZE) {
 		/* set the per-profile filename */
@@ -978,7 +713,6 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 		priv->working_path = NULL;
 
 		/* get from the user */
-		window_tmp = gcm_calibrate_dialog_get_window (priv->calibrate_dialog);
 		priv->working_path = gcm_calibrate_file_chooser_get_working_path (calibrate, window_tmp);
 		if (priv->working_path == NULL) {
 			g_set_error_literal (error,
@@ -1009,7 +743,7 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, GtkWindow *window, GError **erro
 	}
 
 	/* proxy */
-	ret = klass->calibrate_printer (calibrate, priv->sensor, window, error);
+	ret = klass->calibrate_printer (calibrate, device, priv->sensor, window, error);
 out:
 	g_free (precision);
 	return ret;
@@ -1019,122 +753,24 @@ out:
  * gcm_calibrate_device:
  **/
 gboolean
-gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_device (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *window, GError **error)
 {
 	gboolean ret = FALSE;
-	gboolean has_shared_targets;
+	gboolean has_shared_targets = TRUE;
 	gchar *reference_image = NULL;
 	gchar *reference_data = NULL;
-	gchar *device = NULL;
+	gchar *device_str = NULL;
 	const gchar *directory;
 	GString *string;
-	GtkResponseType response;
-	GtkWindow *window_tmp;
+	GtkWindow *window_tmp = NULL;
 	gchar *precision = NULL;
-#ifdef HAVE_PACKAGEKIT
-	GtkWidget *dialog;
-#endif
-	const gchar *title;
 	GcmCalibratePrivate *priv = calibrate->priv;
 	GcmCalibrateClass *klass = GCM_CALIBRATE_GET_CLASS (calibrate);
 
 	string = g_string_new ("");
 
-	/* install shared-color-targets package */
-	has_shared_targets = g_file_test ("/usr/share/shared-color-targets", G_FILE_TEST_IS_DIR);
-	if (!has_shared_targets) {
-#ifdef HAVE_PACKAGEKIT
-		/* ask the user to confirm */
-		dialog = gtk_message_dialog_new (window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-						 /* TRANSLATORS: title, usually we can tell based on the EDID data or output name */
-						 _("Install missing files?"));
-
-		/* TRANSLATORS: dialog message saying the color targets are not installed */
-		g_string_append_printf (string, "%s ", _("Common color target files are not installed on this computer."));
-		/* TRANSLATORS: dialog message saying the color targets are not installed */
-		g_string_append_printf (string, "%s\n\n", _("Color target files are needed to convert the image to a color profile."));
-		/* TRANSLATORS: dialog message, asking if it's okay to install them */
-		g_string_append_printf (string, "%s\n\n", _("Do you want them to be installed?"));
-		/* TRANSLATORS: dialog message, if the user has the target file on a CDROM then there's no need for this package */
-		g_string_append_printf (string, "%s", _("If you already have the correct file, you can skip this step."));
-
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", string->str);
-		gtk_window_set_icon_name (GTK_WINDOW (dialog), GCM_STOCK_ICON);
-		/* TRANSLATORS: button, skip installing a package */
-		gtk_dialog_add_button (GTK_DIALOG (dialog), _("Do not install"), GTK_RESPONSE_CANCEL);
-		/* TRANSLATORS: button, install a package */
-		gtk_dialog_add_button (GTK_DIALOG (dialog), _("Install"), GTK_RESPONSE_YES);
-		response = gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-
-		/* only install if the user wanted to */
-		if (response == GTK_RESPONSE_YES)
-			has_shared_targets = gcm_utils_install_package (GCM_PREFS_PACKAGE_NAME_SHARED_COLOR_TARGETS, window);
-#else
-		g_warning ("cannot install: this package was not compiled with --enable-packagekit");
-#endif
-	}
-
-	/* TRANSLATORS: this is the window title for when the user selects the calibration target.
-	 * A calibration target is an accuratly printed grid of colors, for instance:
-	 * the IT 8.7 targets available here: http://www.targets.coloraid.de/ */
-	title = _("Please select a calibration target");
-	g_string_set_size (string, 0);
-
-	/* TRANSLATORS: dialog message, preface. A calibration target looks like
-	 * this: http://www.colorreference.de/targets/target.jpg */
-	g_string_append_printf (string, "%s\n", _("Before profiling the device, you have to manually capture an image of a calibration target and save it as a TIFF image file."));
-
-	/* scanner specific options */
-	if (priv->device_kind == CD_DEVICE_KIND_SCANNER) {
-		/* TRANSLATORS: dialog message, preface */
-		g_string_append_printf (string, "%s\n", _("Ensure that the contrast and brightness are not changed and color correction profiles have not been applied."));
-
-		/* TRANSLATORS: dialog message, suffix */
-		g_string_append_printf (string, "%s\n", _("The device sensor should have been cleaned prior to scanning and the output file resolution should be at least 200dpi."));
-	}
-
-	/* camera specific options */
-	if (priv->device_kind == CD_DEVICE_KIND_CAMERA) {
-		/* TRANSLATORS: dialog message, preface */
-		g_string_append_printf (string, "%s\n", _("Ensure that the white-balance has not been modified by the camera and that the lens is clean."));
-	}
-
-	/* TRANSLATORS: this is the message body for the chart selection */
-	g_string_append_printf (string, "\n%s", _("Please select the calibration target type."));
-
-	/* push new messages into the UI */
-	gcm_calibrate_dialog_set_window (priv->calibrate_dialog, window);
-	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_TARGET_TYPE, title, string->str);
-	gcm_calibrate_dialog_set_show_button_ok (priv->calibrate_dialog, TRUE);
-	gcm_calibrate_dialog_set_show_expander (priv->calibrate_dialog, FALSE);
-	response = gcm_calibrate_dialog_run (priv->calibrate_dialog);
-	if (response != GTK_RESPONSE_OK) {
-		gcm_calibrate_dialog_hide (priv->calibrate_dialog);
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "user did not choose calibration target type");
-		ret = FALSE;
-		goto out;
-	}
-
-	/* copy */
-	g_object_get (priv->calibrate_dialog, "reference-kind", &priv->reference_kind, NULL);
-
-	/* get default precision */
-	priv->precision = g_settings_get_enum (priv->settings, GCM_SETTINGS_CALIBRATION_LENGTH);
-	if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-		priv->precision = gcm_calibrate_get_precision (calibrate, error);
-		if (priv->precision == GCM_CALIBRATE_PRECISION_UNKNOWN) {
-			ret = FALSE;
-			goto out;
-		}
-	}
-
 	/* get scanned image */
 	directory = g_get_home_dir ();
-	window_tmp = gcm_calibrate_dialog_get_window (priv->calibrate_dialog);
 	reference_image = gcm_calibrate_device_get_reference_image (directory, window_tmp);
 	if (reference_image == NULL) {
 		g_set_error_literal (error,
@@ -1163,9 +799,9 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 	}
 
 	/* use the ORIGINATOR in the it8 file */
-	device = gcm_calibrate_get_device_for_it8_file (reference_data);
-	if (device == NULL)
-		device = g_strdup ("IT8.7");
+	device_str = gcm_calibrate_get_device_for_it8_file (reference_data);
+	if (device_str == NULL)
+		device_str = g_strdup ("IT8.7");
 
 	/* set the calibration parameters */
 	g_object_set (calibrate,
@@ -1174,11 +810,6 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 		      "device", device,
 		      NULL);
 
-	/* set the per-profile filename */
-	ret = gcm_calibrate_set_working_path (calibrate, error);
-	if (!ret)
-		goto out;
-
 	/* coldplug source */
 	if (klass->calibrate_device == NULL) {
 		g_set_error_literal (error,
@@ -1189,17 +820,53 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 	}
 
 	/* proxy */
-	ret = klass->calibrate_device (calibrate, priv->sensor, window, error);
+	ret = klass->calibrate_device (calibrate, device, priv->sensor, window, error);
 out:
 	if (string != NULL)
 		g_string_free (string, TRUE);
 	g_free (precision);
-	g_free (device);
+	g_free (device_str);
 	g_free (reference_image);
 	g_free (reference_data);
 	return ret;
 }
 
+void
+gcm_calibrate_set_title (GcmCalibrate *calibrate, const gchar *title)
+{
+	g_signal_emit (calibrate, signals[SIGNAL_TITLE_CHANGED], 0, title);
+	g_ptr_array_add (calibrate->priv->old_title, g_strdup (title));
+}
+
+void
+gcm_calibrate_set_message (GcmCalibrate *calibrate, const gchar *message)
+{
+	g_signal_emit (calibrate, signals[SIGNAL_MESSAGE_CHANGED], 0, message);
+	g_ptr_array_add (calibrate->priv->old_message, g_strdup (message));
+}
+
+void
+gcm_calibrate_set_image (GcmCalibrate *calibrate, const gchar *filename)
+{
+	g_signal_emit (calibrate, signals[SIGNAL_IMAGE_CHANGED], 0, filename);
+}
+
+void
+gcm_calibrate_interaction_required (GcmCalibrate *calibrate, const gchar *button_text)
+{
+	g_signal_emit (calibrate, signals[SIGNAL_INTERACTION_REQUIRED], 0, button_text);
+}
+
+void
+gcm_calibrate_pop (GcmCalibrate *calibrate)
+{
+	const gchar *tmp;
+	tmp = g_ptr_array_index (calibrate->priv->old_title, calibrate->priv->old_title->len - 2);
+	g_signal_emit (calibrate, signals[SIGNAL_TITLE_CHANGED], 0, tmp);
+	tmp = g_ptr_array_index (calibrate->priv->old_message, calibrate->priv->old_message->len - 2);
+	g_signal_emit (calibrate, signals[SIGNAL_MESSAGE_CHANGED], 0, tmp);
+}
+
 /**
  * gcm_calibrate_get_property:
  **/
@@ -1219,11 +886,12 @@ gcm_calibrate_get_property (GObject *object, guint prop_id, GValue *value, GPara
 	case PROP_PRINT_KIND:
 		g_value_set_uint (value, priv->print_kind);
 		break;
-	case PROP_CALIBRATE_DEVICE_KIND:
-		g_value_set_uint (value, priv->calibrate_device_kind);
+	case PROP_DISPLAY_KIND:
+		g_value_set_uint (value, priv->display_kind);
 		break;
 	case PROP_SENSOR_KIND:
-		g_value_set_uint (value, priv->sensor_kind);
+		g_assert (priv->sensor != NULL);
+		g_value_set_uint (value, cd_sensor_get_kind (priv->sensor));
 		break;
 	case PROP_OUTPUT_NAME:
 		g_value_set_string (value, priv->output_name);
@@ -1270,20 +938,6 @@ gcm_calibrate_get_property (GObject *object, guint prop_id, GValue *value, GPara
 	}
 }
 
-/**
- * gcm_calibrate_guess_kind:
- **/
-static void
-gcm_calibrate_guess_kind (GcmCalibrate *calibrate)
-{
-	gboolean ret;
-	GcmCalibratePrivate *priv = calibrate->priv;
-
-	/* guess based on the output name */
-	ret = gcm_utils_output_is_lcd_internal (priv->output_name);
-	if (ret)
-		priv->calibrate_device_kind = GCM_CALIBRATE_DEVICE_KIND_LCD;
-}
 
 /**
  * gcm_calibrate_set_property:
@@ -1298,7 +952,6 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 	case PROP_OUTPUT_NAME:
 		g_free (priv->output_name);
 		priv->output_name = g_strdup (g_value_get_string (value));
-		gcm_calibrate_guess_kind (calibrate);
 		break;
 	case PROP_FILENAME_SOURCE:
 		g_free (priv->filename_source);
@@ -1340,6 +993,12 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 	case PROP_DEVICE_KIND:
 		priv->device_kind = g_value_get_uint (value);
 		break;
+	case PROP_PRECISION:
+		priv->precision = g_value_get_uint (value);
+		break;
+	case PROP_DISPLAY_KIND:
+		priv->display_kind = g_value_get_uint (value);
+		break;
 	case PROP_WORKING_PATH:
 		g_free (priv->working_path);
 		priv->working_path = g_strdup (g_value_get_string (value));
@@ -1367,150 +1026,121 @@ gcm_calibrate_class_init (GcmCalibrateClass *klass)
 	object_class->get_property = gcm_calibrate_get_property;
 	object_class->set_property = gcm_calibrate_set_property;
 
-	/**
-	 * GcmCalibrate:reference-kind:
-	 */
 	pspec = g_param_spec_uint ("reference-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READABLE);
 	g_object_class_install_property (object_class, PROP_REFERENCE_KIND, pspec);
 
-	/**
-	 * GcmCalibrate:calibrate-device-kind:
-	 */
-	pspec = g_param_spec_uint ("calibrate-device-kind", NULL, NULL,
+	pspec = g_param_spec_uint ("display-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
-				   G_PARAM_READABLE);
-	g_object_class_install_property (object_class, PROP_CALIBRATE_DEVICE_KIND, pspec);
+				   G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_DISPLAY_KIND, pspec);
 
-	/**
-	 * GcmCalibrate:print-kind:
-	 */
 	pspec = g_param_spec_uint ("print-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READABLE);
 	g_object_class_install_property (object_class, PROP_PRINT_KIND, pspec);
 
-	/**
-	 * GcmCalibrate:device-kind:
-	 */
 	pspec = g_param_spec_uint ("device-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_DEVICE_KIND, pspec);
 
-	/**
-	 * GcmCalibrate:sensor-kind:
-	 */
 	pspec = g_param_spec_uint ("sensor-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READABLE);
 	g_object_class_install_property (object_class, PROP_SENSOR_KIND, pspec);
 
-	/**
-	 * GcmCalibrate:output-name:
-	 */
 	pspec = g_param_spec_string ("output-name", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_OUTPUT_NAME, pspec);
 
-	/**
-	 * GcmCalibrate:filename-source:
-	 */
 	pspec = g_param_spec_string ("filename-source", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_FILENAME_SOURCE, pspec);
 
-	/**
-	 * GcmCalibrate:filename-reference:
-	 */
 	pspec = g_param_spec_string ("filename-reference", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_FILENAME_REFERENCE, pspec);
 
-	/**
-	 * GcmCalibrate:filename-result:
-	 */
 	pspec = g_param_spec_string ("filename-result", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_FILENAME_RESULT, pspec);
 
-	/**
-	 * GcmCalibrate:basename:
-	 */
 	pspec = g_param_spec_string ("basename", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_BASENAME, pspec);
 
-	/**
-	 * GcmCalibrate:model:
-	 */
 	pspec = g_param_spec_string ("model", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_MODEL, pspec);
 
-	/**
-	 * GcmCalibrate:description:
-	 */
 	pspec = g_param_spec_string ("description", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_DESCRIPTION, pspec);
 
-	/**
-	 * GcmCalibrate:serial:
-	 */
 	pspec = g_param_spec_string ("serial", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_SERIAL, pspec);
 
-	/**
-	 * GcmCalibrate:device:
-	 */
 	pspec = g_param_spec_string ("device", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_DEVICE, pspec);
 
-	/**
-	 * GcmCalibrate:manufacturer:
-	 */
 	pspec = g_param_spec_string ("manufacturer", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_MANUFACTURER, pspec);
 
-	/**
-	 * GcmCalibrate:working-path:
-	 */
 	pspec = g_param_spec_string ("working-path", NULL, NULL,
 				     NULL,
 				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_WORKING_PATH, pspec);
 
-	/**
-	 * GcmCalibrate:precision:
-	 */
 	pspec = g_param_spec_uint ("precision", NULL, NULL,
 				   0, G_MAXUINT, 0,
-				   G_PARAM_READABLE);
+				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_PRECISION, pspec);
 
-	/**
-	 * GcmCalibrate:xyz:
-	 */
 	pspec = g_param_spec_boxed ("xyz", NULL, NULL,
 				    CD_TYPE_COLOR_XYZ,
 				    G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_XYZ, pspec);
 
+	signals[SIGNAL_TITLE_CHANGED] =
+		g_signal_new ("title-changed",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GcmCalibrateClass, title_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
+	signals[SIGNAL_MESSAGE_CHANGED] =
+		g_signal_new ("message-changed",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GcmCalibrateClass, message_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
+	signals[SIGNAL_IMAGE_CHANGED] =
+		g_signal_new ("image-changed",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GcmCalibrateClass, image_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
+	signals[SIGNAL_INTERACTION_REQUIRED] =
+		g_signal_new ("interaction-required",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GcmCalibrateClass, interaction_required),
+			      NULL, NULL, g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
+
 	g_type_class_add_private (klass, sizeof (GcmCalibratePrivate));
 }
 
@@ -1521,29 +1151,16 @@ static void
 gcm_calibrate_init (GcmCalibrate *calibrate)
 {
 	calibrate->priv = GCM_CALIBRATE_GET_PRIVATE (calibrate);
-	calibrate->priv->output_name = NULL;
-	calibrate->priv->filename_source = NULL;
-	calibrate->priv->filename_reference = NULL;
-	calibrate->priv->filename_result = NULL;
-	calibrate->priv->basename = NULL;
-	calibrate->priv->manufacturer = NULL;
-	calibrate->priv->model = NULL;
-	calibrate->priv->description = NULL;
-	calibrate->priv->device = NULL;
-	calibrate->priv->serial = NULL;
 	calibrate->priv->xyz = cd_color_xyz_new ();
-	calibrate->priv->working_path = NULL;
-	calibrate->priv->calibrate_device_kind = GCM_CALIBRATE_DEVICE_KIND_UNKNOWN;
+
 	calibrate->priv->print_kind = GCM_CALIBRATE_PRINT_KIND_UNKNOWN;
 	calibrate->priv->reference_kind = GCM_CALIBRATE_REFERENCE_KIND_UNKNOWN;
 	calibrate->priv->precision = GCM_CALIBRATE_PRECISION_UNKNOWN;
-	calibrate->priv->calibrate_dialog = gcm_calibrate_dialog_new ();
 
 	// FIXME: this has to be per-run specific
 	calibrate->priv->working_path = g_strdup ("/tmp");
-
-	/* use GSettings to get defaults */
-	calibrate->priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
+	calibrate->priv->old_title = g_ptr_array_new_with_free_func (g_free);
+	calibrate->priv->old_message = g_ptr_array_new_with_free_func (g_free);
 }
 
 /**
@@ -1567,8 +1184,8 @@ gcm_calibrate_finalize (GObject *object)
 	g_free (priv->serial);
 	g_free (priv->working_path);
 	cd_color_xyz_free (priv->xyz);
-	g_object_unref (priv->calibrate_dialog);
-	g_object_unref (priv->settings);
+	g_ptr_array_unref (calibrate->priv->old_title);
+	g_ptr_array_unref (calibrate->priv->old_message);
 
 	G_OBJECT_CLASS (gcm_calibrate_parent_class)->finalize (object);
 }
@@ -1585,4 +1202,3 @@ gcm_calibrate_new (void)
 	calibrate = g_object_new (GCM_TYPE_CALIBRATE, NULL);
 	return GCM_CALIBRATE (calibrate);
 }
-
