@@ -32,14 +32,12 @@
 #include <lcms2.h>
 #include <colord.h>
 
-#include "gcm-calibrate-argyll.h"
 #include "gcm-utils.h"
 #include "gcm-debug.h"
 
 static CdClient *client = NULL;
 static const gchar *profile_filename = NULL;
 static gboolean done_measure = FALSE;
-static GcmCalibrate *calibrate = NULL;
 static CdColorXYZ last_sample;
 static CdSensor *sensor = NULL;
 static gdouble last_ambient = -1.0f;
@@ -254,100 +252,66 @@ gcm_picker_got_results (void)
 static void
 gcm_picker_measure_cb (GtkWidget *widget, gpointer data)
 {
-	GtkWindow *window;
 	gboolean ret;
+	CdColorXYZ *tmp = NULL;
 	GError *error = NULL;
 
 	/* reset the image */
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "image_preview"));
 	gtk_image_set_from_file (GTK_IMAGE (widget), DATADIR "/icons/hicolor/64x64/apps/gnome-color-manager.png");
 
-	if (cd_sensor_get_native (sensor)) {
-
-		/* lock */
-		ret = cd_sensor_lock_sync (sensor,
-					   NULL,
-					   &error);
-		if (!ret) {
-			g_warning ("failed to lock: %s", error->message);
-			g_error_free (error);
-			goto out;
-		}
-
-		/* get color */
-		ret = cd_sensor_get_sample_sync (sensor,
-						 CD_SENSOR_CAP_LCD,
-						 &last_sample,
-						 NULL,
-						 NULL,
-						 &error);
-		if (!ret) {
-			g_warning ("failed to get ambient: %s", error->message);
-			g_error_free (error);
-			goto out;
-		}
-
-		/* get ambient */
-		ret = cd_sensor_get_sample_sync (sensor,
-						 CD_SENSOR_CAP_AMBIENT,
-						 NULL,
-						 &last_ambient,
-						 NULL,
-						 &error);
-		if (!ret) {
-			g_warning ("failed to get ambient: %s", error->message);
-			g_error_free (error);
-			goto out;
-		}
-
-		/* unlock */
-		ret = cd_sensor_unlock_sync (sensor,
-					     NULL,
-					     &error);
-		if (!ret) {
-			g_warning ("failed to lock: %s", error->message);
-			g_error_free (error);
-			goto out;
-		}
-
-		gcm_picker_refresh_results ();
-		gcm_picker_got_results ();
-	} else {
-		/* get value */
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_picker"));
-		ret = gcm_calibrate_spotread (calibrate, window, &error);
-		if (!ret) {
-			g_warning ("failed to get spot color: %s", error->message);
-			g_error_free (error);
-			goto out;
-		}
+	/* lock */
+	ret = cd_sensor_lock_sync (sensor,
+				   NULL,
+				   &error);
+	if (!ret) {
+		g_warning ("failed to lock: %s", error->message);
+		g_error_free (error);
+		goto out;
 	}
-out:
-	return;
-}
 
-/**
- * gcm_picker_xyz_notify_cb:
- **/
-static void
-gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_,
-			  GParamSpec *pspec,
-			  gpointer user_data)
-{
-	CdColorXYZ *xyz;
+	/* get color */
+	tmp = cd_sensor_get_sample_sync (sensor,
+					 CD_SENSOR_CAP_LCD,
+					 NULL,
+					 &error);
+	if (tmp == NULL) {
+		g_warning ("failed to get sample: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+	cd_color_copy_xyz (tmp, &last_sample);
+#if 0
+	/* get ambient */
+	ret = cd_sensor_get_sample_sync (sensor,
+					 CD_SENSOR_CAP_AMBIENT,
+					 NULL,
+					 &last_ambient,
+					 NULL,
+					 &error);
+	if (!ret) {
+		g_warning ("failed to get ambient: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+#endif
 
-	/* get new value */
-	g_object_get (calibrate, "xyz", &xyz, NULL);
-
-	g_object_get (xyz,
-		      "cie-x", &last_sample.X,
-		      "cie-y", &last_sample.Y,
-		      "cie-z", &last_sample.Z,
-		      NULL);
+	/* unlock */
+	ret = cd_sensor_unlock_sync (sensor,
+				     NULL,
+				     &error);
+	if (!ret) {
+		g_warning ("failed to lock: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
 
 	gcm_picker_refresh_results ();
 	gcm_picker_got_results ();
-	cd_color_xyz_free (xyz);
+out:
+	if (tmp != NULL)
+		cd_color_xyz_free (tmp);
+	return;
 }
 
 /**
@@ -405,14 +369,12 @@ gcm_picker_sensor_client_setup_ui (void)
 	}
 	sensor = g_object_ref (g_ptr_array_index (sensors, 0));
 
-#ifndef HAVE_VTE
 	if (!cd_sensor_get_native (sensor)) {
 		 /* TRANSLATORS: this is displayed if VTE support is not enabled */
 		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label),
-				     _("This application was compiled without VTE support."));
+				     _("The sensor has no native driver."));
 		goto out;
 	}
-#endif
 
 #if 0
 	/* no support */
@@ -573,6 +535,7 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 	gboolean has_profile = FALSE;
 	gboolean has_vcgt;
 	gchar *text = NULL;
+	gboolean ret;
 	GError *error = NULL;
 	GPtrArray *devices = NULL;
 	GPtrArray *profile_array = NULL;
@@ -595,6 +558,15 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 	for (i=0; i<profile_array->len; i++) {
 		profile = g_ptr_array_index (profile_array, i);
 
+		/* connect to the profile */
+		ret = cd_profile_connect_sync (profile, NULL, &error);
+		if (!ret) {
+			g_warning ("failed to connect to profile: %s",
+				   error->message);
+			g_error_free (error);
+			goto out;
+		}
+
 		/* only for correct kind */
 		has_vcgt = cd_profile_get_has_vcgt (profile);
 		has_colorspace_description = gcm_profile_has_colorspace_description (profile);
@@ -618,10 +590,29 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 						      &error);
 	for (i=0; i<devices->len; i++) {
 		device_tmp = g_ptr_array_index (devices, i);
+
+		/* connect to the device */
+		ret = cd_device_connect_sync (device_tmp, NULL, &error);
+		if (!ret) {
+			g_warning ("failed to connect to device: %s",
+				   error->message);
+			g_error_free (error);
+			goto out;
+		}
+
 		profile = cd_device_get_default_profile (device_tmp);
 		if (profile == NULL)
 			continue;
 
+		/* connect to the profile */
+		ret = cd_profile_connect_sync (profile, NULL, &error);
+		if (!ret) {
+			g_warning ("failed to connect to profile: %s",
+				   error->message);
+			g_error_free (error);
+			goto out;
+		}
+
 		/* add device profile */
 		gcm_prefs_combobox_add_profile (widget, profile, NULL);
 		g_object_unref (profile);
@@ -717,11 +708,6 @@ gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 		gcm_window_set_parent_xid (GTK_WINDOW (main_window), xid);
 	}
 
-	/* use argyll */
-	calibrate = GCM_CALIBRATE (gcm_calibrate_argyll_new ());
-	g_signal_connect (calibrate, "notify::xyz",
-			  G_CALLBACK (gcm_picker_xyz_notify_cb), NULL);
-
 	/* use an info bar if there is no device, or the wrong device */
 	info_bar_hardware = gtk_info_bar_new ();
 	info_bar_hardware_label = gtk_label_new (NULL);
@@ -826,8 +812,6 @@ main (int argc, char *argv[])
 	g_object_unref (application);
 	if (client != NULL)
 		g_object_unref (client);
-	if (calibrate != NULL)
-		g_object_unref (calibrate);
 	if (builder != NULL)
 		g_object_unref (builder);
 	return status;
