@@ -32,26 +32,6 @@
 #define GCM_DBUS_INTERFACE				"org.gnome.ColorManager"
 #define GCM_DBUS_PATH					"/org/gnome/ColorManager"
 
-#define GCM_SETTINGS_SCHEMA				"org.gnome.color-manager"
-#define GCM_SETTINGS_DEFAULT_GAMMA			"default-gamma"
-#define GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION		"global-display-correction"
-#define GCM_SETTINGS_SET_ICC_PROFILE_ATOM		"set-icc-profile-atom"
-#define GCM_SETTINGS_RENDERING_INTENT_DISPLAY		"rendering-intent-display"
-#define GCM_SETTINGS_RENDERING_INTENT_SOFTPROOF		"rendering-intent-softproof"
-#define GCM_SETTINGS_COLORSPACE_RGB			"colorspace-rgb"
-#define GCM_SETTINGS_COLORSPACE_CMYK			"colorspace-cmyk"
-#define GCM_SETTINGS_COLORSPACE_GRAY			"colorspace-gray"
-#define GCM_SETTINGS_CALIBRATION_LENGTH			"calibration-length"
-#define GCM_SETTINGS_SHOW_FINE_TUNING			"show-fine-tuning"
-#define GCM_SETTINGS_SHOW_NOTIFICATIONS			"show-notifications"
-#define GCM_SETTINGS_RECALIBRATE_PRINTER_THRESHOLD	"recalibrate-printer-threshold"
-#define GCM_SETTINGS_RECALIBRATE_DISPLAY_THRESHOLD	"recalibrate-display-threshold"
-#define GCM_SETTINGS_ENABLE_SANE			"enable-sane"
-#define GCM_SETTINGS_PROFILE_GRAPH_TYPE			"profile-graph-type"
-
-#define GCM_CONFIG_VERSION_ORIGINAL			0
-#define GCM_CONFIG_VERSION_SHARED_SPEC			1
-
 /* DISTROS: you will have to patch if you have changed the name of these packages */
 #define GCM_PREFS_PACKAGE_NAME_SHARED_COLOR_TARGETS	"shared-color-targets"
 #define GCM_PREFS_PACKAGE_NAME_ARGYLLCMS		"argyllcms"
