@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2011 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -59,7 +59,6 @@ typedef struct {
 	GtkWidget	*vcgt_widget;
 	GtkWidget	*preview_widget_input;
 	GtkWidget	*preview_widget_output;
-	GSettings	*settings;
 	guint		 example_index;
 	gchar		*profile_id;
 	guint		 xid;
@@ -222,6 +221,7 @@ gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 	CdProfile *profile;
 	guint i;
 	const gchar *filename = NULL;
+	gboolean ret;
 	gchar *sort = NULL;
 	GPtrArray *profile_array = NULL;
 	GError *error = NULL;
@@ -246,14 +246,25 @@ gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 	for (i=0; i<profile_array->len; i++) {
 		profile = g_ptr_array_index (profile_array, i);
 
+		/* connect to the profile */
+		ret = cd_profile_connect_sync (profile, NULL, &error);
+		if (!ret) {
+			g_warning ("failed to connect to profile: %s",
+				   error->message);
+			g_error_free (error);
+			goto out;
+		}
+
 		profile_kind = cd_profile_get_kind (profile);
 		icon_name = gcm_viewer_profile_kind_to_icon_name (profile_kind);
 		gtk_list_store_append (viewer->list_store_profiles, &iter);
+		filename = cd_profile_get_filename (profile);
+		if (filename == NULL)
+			continue;
 		description = cd_profile_get_title (profile);
 		sort = g_strdup_printf ("%s%s",
 					gcm_viewer_profile_get_sort_string (profile_kind),
 					description);
-		filename = cd_profile_get_filename (profile);
 		g_debug ("add %s to profiles list", filename);
 		gtk_list_store_set (viewer->list_store_profiles, &iter,
 				    GCM_PROFILES_COLUMN_ID, filename,
@@ -682,6 +693,36 @@ out:
 	return ret;
 }
 
+struct {
+	const gchar *key;
+	const gchar *localised;
+} metadata_keys[] = {
+	{ CD_PROFILE_METADATA_STANDARD_SPACE,		N_("Standard space") },
+	{ CD_PROFILE_METADATA_EDID_MD5,			N_("Display checksum") },
+	{ CD_PROFILE_METADATA_EDID_MODEL,		N_("Display model") },
+	{ CD_PROFILE_METADATA_EDID_SERIAL,		N_("Display serial number") },
+	{ CD_PROFILE_METADATA_EDID_MNFT,		N_("Display PNPID") },
+	{ CD_PROFILE_METADATA_EDID_VENDOR,		N_("Display vendor") },
+	{ CD_PROFILE_METADATA_FILE_CHECKSUM,		N_("File checksum") },
+	{ CD_PROFILE_METADATA_CMF_PRODUCT,		N_("Framework product") },
+	{ CD_PROFILE_METADATA_CMF_BINARY,		N_("Framework program") },
+	{ CD_PROFILE_METADATA_CMF_VERSION,		N_("Framework version") },
+	{ CD_PROFILE_METADATA_DATA_SOURCE,		N_("Data source type") },
+	{ CD_PROFILE_METADATA_MAPPING_FORMAT,		N_("Mapping format") },
+	{ CD_PROFILE_METADATA_MAPPING_QUALIFIER,	N_("Mapping qualifier") },
+	{ NULL, NULL }
+};
+
+static const gchar *
+gcm_viewer_get_localised_metadata_key (const gchar *key)
+{
+	guint i;
+	for (i = 0; metadata_keys[i].key != NULL; i++) {
+		if (g_strcmp0 (key, metadata_keys[i].key) == 0)
+			return metadata_keys[i].localised;
+	}
+	return key;
+}
 
 /**
  * gcm_viewer_add_metadata:
@@ -697,6 +738,7 @@ gcm_viewer_add_metadata (GcmViewerPrivate *viewer,
 	GList *l;
 	GtkTreeIter iter;
 	const gchar *value;
+	const gchar *key;
 
 	/* clear existing */
 	gtk_list_store_clear (viewer->liststore_metadata);
@@ -714,13 +756,14 @@ gcm_viewer_add_metadata (GcmViewerPrivate *viewer,
 	if (keys == NULL)
 		goto out;
 	for (l = keys; l != NULL; l = l->next) {
+		key = gcm_viewer_get_localised_metadata_key ((gchar *) l->data);
 		value = g_hash_table_lookup (metadata, l->data);
 		g_debug ("Adding '%s', '%s'",
-			 (const gchar *) l->data, value);
+			 key, value);
 		gtk_list_store_append (viewer->liststore_metadata, &iter);
 		gtk_list_store_set (viewer->liststore_metadata,
 				    &iter,
-				    GCM_METADATA_COLUMN_KEY, l->data,
+				    GCM_METADATA_COLUMN_KEY, key,
 				    GCM_METADATA_COLUMN_VALUE, value,
 				    -1);
 	}
@@ -1206,9 +1249,6 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	GtkWidget *main_window;
 	GtkWidget *widget;
 
-	/* setup defaults */
-	viewer->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
-
 	/* get UI */
 	viewer->builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (viewer->builder,
@@ -1511,8 +1551,6 @@ main (int argc, char **argv)
 	status = g_application_run (G_APPLICATION (viewer->application), argc, argv);
 
 	g_object_unref (viewer->application);
-	if (viewer->settings != NULL)
-		g_object_unref (viewer->settings);
 	if (viewer->builder != NULL)
 		g_object_unref (viewer->builder);
 	if (viewer->client != NULL)
